@@ -1,10 +1,10 @@
 from __future__ import absolute_import
 
 import uuid
-from typing import Any, Iterable, List
+from typing import Any, Iterable
 
 
-def to_uuid(*args: List[Any]) -> str:
+def to_uuid(*args: Any) -> str:
     """Determine the uuid by input arguments. It will search the input recursively.
     If an object contains `__uuid__` method, it will call that method to get the uuid
     for that object.
